@@ -18,7 +18,7 @@
 #' unlink(db)
 change.info <- function(name = "", installed = TRUE, source.dir = "", bin.dir = "", 
   executable.files = "", db = Sys.getenv("BIO_SOFTWARES_DB_ACTIVE", system.file("extdata", 
-    "softwares_db_demo.yaml", package = "BioInstaller")), ..., verbose = TRUE) {
+    "demo/softwares_db_demo.yaml", package = "BioInstaller")), ..., verbose = TRUE) {
   msg <- sprintf("Running change.info for %s and be saved to %s", name, db)
   info.msg(msg, verbose = verbose)
   source.dir <- normalizePath(source.dir, mustWork = F)
@@ -52,7 +52,7 @@ change.info <- function(name = "", installed = TRUE, source.dir = "", bin.dir =
 #' get.info('bwa')
 #' unlink(db)
 get.info <- function(name = "", db = Sys.getenv("BIO_SOFTWARES_DB_ACTIVE", system.file("extdata", 
-  "softwares_db_demo.yaml", package = "BioInstaller")), verbose = TRUE) {
+  "demo/softwares_db_demo.yaml", package = "BioInstaller")), verbose = TRUE) {
   db <- normalizePath(db, mustWork = FALSE)
   if (!db.check(db)) {
     return(FALSE)
@@ -84,7 +84,7 @@ get.info <- function(name = "", db = Sys.getenv("BIO_SOFTWARES_DB_ACTIVE", syste
 #' del.info('bwa')
 #' unlink(db)
 del.info <- function(name = "", db = Sys.getenv("BIO_SOFTWARES_DB_ACTIVE", system.file("extdata", 
-  "softwares_db_demo.yaml", package = "BioInstaller")), verbose = TRUE) {
+  "demo/softwares_db_demo.yaml", package = "BioInstaller")), verbose = TRUE) {
   db <- normalizePath(db, mustWork = FALSE)
   if (!db.check(db)) {
     return(FALSE)
@@ -117,7 +117,7 @@ del.info <- function(name = "", db = Sys.getenv("BIO_SOFTWARES_DB_ACTIVE", syste
 #' show.installed()
 #' unlink(db)
 show.installed <- function(db = Sys.getenv("BIO_SOFTWARES_DB_ACTIVE", system.file("extdata", 
-  "softwares_db_demo.yaml", package = "BioInstaller")), only.installed = TRUE, 
+  "demo/softwares_db_demo.yaml", package = "BioInstaller")), only.installed = TRUE, 
   verbose = TRUE) {
   db <- normalizePath(db, mustWork = FALSE)
   if (!db.check(db)) {
